# Pretty library change log

## 1.0.1 -- 26th January, 2022

* Fix compatibility issues with pypi. :package:
* Moved runner from [\_\_init__.py](./src/__init__.py) to [\_\_main__.py](./src/__main__.py). :runner:
* Updated [README.md](README.md) :zap:
* Added module level functions `encode` and decode in `decode` in [\_\_init__.py](src/__init__.py) to improve accessibility :wheelchair:

